@@ -27,12 +27,6 @@ list = list_encodings  # not included in __all__ because of shadow name
 reset()
 
 
-# overwritten native codec
-add("uu", lambda i, e="strict": orig_lookup("uu").encode(b(i), e),
-          lambda i, e="strict": orig_lookup("uu").decode(b(i), e),
-          pattern=r"^uu(?:[-_]encode|codec)?$", add_to_codecs=True, category="native")
-
-
 def __format_list(items, include=True):
     if items is None:
         return
